@@ -260,7 +260,8 @@ class Entry(TreeInheritable, OwnedModel):
     def get_column(self):
         return self.column.descendant
     
-    def increment_view_count(self):
+    def increment_view_count(self, request):
+        if request.user.is_staff or self.user == request.user: return
         self.view_count = models.F("view_count")+1
         self.save() 
     
